@@ -23,7 +23,7 @@
         if (!val)                                                            \
             ErrorMayQuit(funcname ": method should have returned a value",   \
                          0, 0);                                              \
-    } while (0);
+    } while (0)
 
 
 /****************************************************************************
