@@ -36,7 +36,7 @@
 #include "hpc/thread.h"
 #endif
 
-#include <stdio.h>
+#include <stdio.h>  // for fprintf
 
 
 static Obj ErrorInner;
@@ -72,9 +72,9 @@ UInt OpenErrorOutput(TypOutputFile * output)
     }
 
     if (!ret) {
-        /* It may be we already tried and failed to open *errout* above but
-         * but this is an extreme case so it can't hurt to try again
-         * anyways */
+        // It may be we already tried and failed to open *errout* above but
+        // but this is an extreme case so it can't hurt to try again
+        // anyways
         ret = OpenOutput(output, "*errout*", FALSE);
         if (ret) {
             Pr("failed to open error stream\n", 0, 0);
@@ -276,8 +276,8 @@ Obj CALL_WITH_CATCH(Obj func, volatile Obj args)
         // in case func was a kernel function.
         TakeInterrupt();
 #ifdef HPCGAP
-        /* There should be no locks to pop off the stack, but better safe than
-         * sorry. */
+        // There should be no locks to pop off the stack, but better safe than
+        // sorry.
         PopRegionLocks(lockSP);
         TLS(currentRegion) = savedRegion;
 #endif
@@ -596,6 +596,23 @@ void AssertionFailure(void)
     ErrorReturnVoid("Assertion failure", 0, 0, "you may 'return;'");
 }
 
+void AssertionFailureWithMessage(Obj message)
+{
+    if (message == 0) {
+        // this case is triggered by code like this: Assert(0, false, Error("boo"));
+        // at least if the user enters `return;` into the break loop opened by this.
+        AssertionFailure();
+    }
+    else if (IS_STRING_REP(message)) {
+        ErrorReturnVoid("Assertion failure: %g", (Int)message, 0, "you may 'return;'");
+    }
+    else {
+        PrintObj(message);
+        Pr("\n", 0, 0);
+        AssertionFailure();
+    }
+}
+
 
 /****************************************************************************
 **
