@@ -22,8 +22,8 @@
 **  entries are the  proper prime powers,  odd entries are the  corresponding
 **  conway polynomials.
 */
-extern const unsigned long PolsFF[]; // FIXME: should be static, but cvec uses it
-const unsigned long PolsFF[] = {
+extern const unsigned int PolsFF[]; // FIXME: should be static, but cvec uses it
+const unsigned int PolsFF[] = {
        4,  1 +2,
        8,  1 +2,
       16,  1 +2,
