@@ -8,7 +8,7 @@
 **  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#include "hpc/cpu.h"
+#include "cpu.h"
 
 #include <unistd.h>
 
