@@ -10,34 +10,34 @@
 **  This file contains the GAP interface for thread primitives.
 */
 
-#include "hpc/threadapi.h"
+#include "threadapi.h"
 
-#include "bool.h"
-#include "calls.h"
-#include "code.h"
-#include "error.h"
-#include "funcs.h"
-#include "gvars.h"
-#include "io.h"
-#include "lists.h"
-#include "modules.h"
-#include "objects.h"
-#include "plist.h"
-#include "precord.h"
-#include "read.h"
-#include "records.h"
-#include "set.h"
-#include "stats.h"
-#include "stringobj.h"
-#include "trycatch.h"
-#include "vars.h"
+#include "../bool.h"
+#include "../calls.h"
+#include "../code.h"
+#include "../error.h"
+#include "../funcs.h"
+#include "../gvars.h"
+#include "../io.h"
+#include "../lists.h"
+#include "../modules.h"
+#include "../objects.h"
+#include "../plist.h"
+#include "../precord.h"
+#include "../read.h"
+#include "../records.h"
+#include "../set.h"
+#include "../stats.h"
+#include "../stringobj.h"
+#include "../trycatch.h"
+#include "../vars.h"
 
-#include "hpc/guards.h"
-#include "hpc/misc.h"
-#include "hpc/region.h"
-#include "hpc/thread.h"
-#include "hpc/tls.h"
-#include "hpc/traverse.h"
+#include "guards.h"
+#include "misc.h"
+#include "region.h"
+#include "thread.h"
+#include "tls.h"
+#include "traverse.h"
 
 #include <signal.h>
 #include <stdio.h>
@@ -2019,7 +2019,7 @@ MigrateObjects(int count, Obj * objects, Region * target, int retype)
     for (i = 0; i < count; i++) {
         Obj obj = objects[i];
         if (TNUM_OBJ(obj) == T_PREC) {
-            SortPRecRNam(obj, 0);
+            SortPRecRNam(obj);
         }
         SET_REGION(obj, target);
     }
