@@ -15,37 +15,15 @@
 
 #include "objects.h"
 
-#ifdef VERY_LONG_DOUBLES
-typedef long double /* __float128 */ Double;
-#define PRINTFDIGITS 20
-#define PRINTFFORMAT "Lg"
-#define STRTOD strtold
-#define MATH(name) name##l
-#else
 typedef double Double;
 #define PRINTFDIGITS 16
 #define PRINTFFORMAT "g"
 #define STRTOD strtod
 #define MATH(name) name
-#endif
-
-EXPORT_INLINE Double VAL_MACFLOAT(Obj obj)
-{
-    Double val;
-    memcpy(&val, CONST_ADDR_OBJ(obj), sizeof(Double));
-    return val;
-}
-
-EXPORT_INLINE void SET_VAL_MACFLOAT(Obj obj, Double val)
-{
-    memcpy(ADDR_OBJ(obj), &val, sizeof(Double));
-}
-
-EXPORT_INLINE  Int IS_MACFLOAT(Obj obj)
-{
-    return TNUM_OBJ(obj) == T_MACFLOAT;
-}
 
+Double VAL_MACFLOAT(Obj obj);
+void SET_VAL_MACFLOAT(Obj obj, Double val);
+BOOL IS_MACFLOAT(Obj obj);
 Obj NEW_MACFLOAT(Double val);
 
 
