@@ -42,6 +42,7 @@
 
 #include <dirent.h>
 #include <errno.h>
+#include <limits.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <time.h>
@@ -245,7 +246,17 @@ static Obj FuncREAD_COMMAND_REAL(Obj self, Obj stream, Obj echo)
     if (!OpenInputStream(&input, stream, echo == True)) {
         return result;
     }
-    ExecStatus status = ReadEvalCommand(0, &input, &evalResult, 0);
+    ExecStatus status;
+
+    GAP_TRY
+    {
+        status = ReadEvalCommand(0, &input, &evalResult, 0);
+    }
+    GAP_CATCH
+    {
+        CloseInput(&input);
+        GAP_THROW();
+    }
     CloseInput(&input);
 
     if (status == STATUS_EOF || status == STATUS_QQUIT)
@@ -404,7 +415,11 @@ Int READ_GAP_ROOT ( const Char * filename )
     }
 
     TypInputFile input;
-    if (OpenInput(&input, path)) {
+    if (!OpenInput(&input, path))
+        return 0;
+
+    GAP_TRY
+    {
         while (1) {
             ExecStatus status = ReadEvalCommand(0, &input, 0, 0);
             if (STATE(UserHasQuit) || STATE(UserHasQUIT))
@@ -416,11 +431,14 @@ Int READ_GAP_ROOT ( const Char * filename )
                 break;
             }
         }
-        CloseInput(&input);
-        return 1;
     }
-
-    return 0;
+    GAP_CATCH
+    {
+        CloseInput(&input);
+        GAP_THROW();
+    }
+    CloseInput(&input);
+    return 1;
 }
 
 
@@ -806,8 +824,17 @@ static Obj FuncREAD(Obj self, Obj inputObj)
     if (!OpenInputFileOrStream(SELF_NAME, &input, inputObj))
         return False;
 
-    // read the file
-    READ_INNER(&input);
+    GAP_TRY
+    {
+        // read the file
+        READ_INNER(&input);
+    }
+    GAP_CATCH
+    {
+        CloseInput(&input);
+        GAP_THROW();
+    }
+
     if (!CloseInput(&input)) {
         ErrorQuit("Panic: READ cannot close input", 0, 0);
     }
@@ -826,9 +853,10 @@ static Obj FuncREAD(Obj self, Obj inputObj)
 static Obj FuncREAD_STREAM_LOOP(Obj self,
                                 Obj instream,
                                 Obj outstream,
-                                Obj context)
+                                Obj ctx)
 {
     Int res;
+    volatile Obj context = ctx;
 
     RequireInputStream(SELF_NAME, instream);
     RequireOutputStream(SELF_NAME, outstream);
@@ -853,41 +881,50 @@ static Obj FuncREAD_STREAM_LOOP(Obj self,
 
     LockCurrentOutput(TRUE);
 
-    // get the starting time
-    UInt oldPrintObjState = SetPrintObjState(0);
+    // save the old print state
+    volatile UInt oldPrintObjState = SetPrintObjState(0);
 
-    // now do the reading
-    while (1) {
-        Obj  evalResult;
-        BOOL dualSemicolon;
-        UInt oldtime = SyTime();
+    BOOL rethrow = FALSE;
 
-        // read and evaluate the command
-        SetPrintObjState(0);
-        ExecStatus status =
-            ReadEvalCommand(context, &input, &evalResult, &dualSemicolon);
+    GAP_TRY
+    {
+        // now do the reading
+        while (1) {
+            Obj  evalResult;
+            BOOL dualSemicolon;
+            UInt oldtime = SyTime();
 
-        // stop the stopwatch
-        UpdateTime(oldtime);
+            // read and evaluate the command
+            SetPrintObjState(0);
+            ExecStatus status =
+                ReadEvalCommand(context, &input, &evalResult, &dualSemicolon);
 
-        // handle ordinary command
-        if (status == STATUS_END && evalResult != 0) {
-            UpdateLast(evalResult);
-            if (!dualSemicolon) {
-                ViewObjHandler(evalResult);
+            // stop the stopwatch
+            UpdateTime(oldtime);
+
+            // handle ordinary command
+            if (status == STATUS_END && evalResult != 0) {
+                UpdateLast(evalResult);
+                if (!dualSemicolon) {
+                    ViewObjHandler(evalResult);
+                }
+            }
+
+            // handle return-value or return-void command
+            else if (status == STATUS_RETURN) {
+                Pr("'return' must not be used in file read-eval loop\n", 0, 0);
+            }
+
+            // handle quit command or <end-of-file>
+            else if (status == STATUS_EOF || status == STATUS_QUIT ||
+                     status == STATUS_QQUIT) {
+                break;
             }
         }
-
-        // handle return-value or return-void command
-        else if (status == STATUS_RETURN) {
-            Pr("'return' must not be used in file read-eval loop\n", 0, 0);
-        }
-
-        // handle quit command or <end-of-file>
-        else if (status == STATUS_EOF || status == STATUS_QUIT ||
-                 status == STATUS_QQUIT) {
-            break;
-        }
+    }
+    GAP_CATCH
+    {
+        rethrow = TRUE;
     }
 
     SetPrintObjState(oldPrintObjState);
@@ -895,10 +932,10 @@ static Obj FuncREAD_STREAM_LOOP(Obj self,
     LockCurrentOutput(FALSE);
 
     res = CloseInput(&input);
-    GAP_ASSERT(res);
-
     res &= CloseOutput(&output);
-    GAP_ASSERT(res);
+
+    if (rethrow)
+        GAP_THROW();
 
     return res ? True : False;
 }
@@ -914,7 +951,18 @@ static Obj FuncREAD_AS_FUNC(Obj self, Obj inputObj)
     if (!OpenInputFileOrStream(SELF_NAME, &input, inputObj))
         return False;
 
-    Obj func = READ_AS_FUNC(&input);
+    Obj func;
+
+    GAP_TRY
+    {
+        func = READ_AS_FUNC(&input);
+    }
+    GAP_CATCH
+    {
+        CloseInput(&input);
+        GAP_THROW();
+    }
+
     if (!CloseInput(&input)) {
         ErrorQuit("Panic: READ_AS_FUNC cannot close input", 0, 0);
     }
@@ -1080,6 +1128,22 @@ static Obj FuncGAP_chdir(Obj self, Obj path)
     return True;
 }
 
+/****************************************************************************
+**
+*F  FuncGAP_realpath( <self>, <path> ) . . . .  TODO
+*/
+static Obj FuncGAP_realpath(Obj self, Obj path)
+{
+    RequireStringRep(SELF_NAME, path);
+    char resolved_path[GAP_PATH_MAX];
+
+    if (NULL == realpath(CONST_CSTR_STRING(path), resolved_path)) {
+        SySetErrorNo();
+        return Fail;
+    }
+    return MakeString(resolved_path);
+}
+
 
 /****************************************************************************
 **
@@ -1716,6 +1780,7 @@ static StructGVarFunc GVarFuncs[] = {
     GVAR_FUNC_1ARGS(IS_DIR, path),
     GVAR_FUNC_0ARGS(GAP_getcwd),
     GVAR_FUNC_1ARGS(GAP_chdir, path),
+    GVAR_FUNC_1ARGS(GAP_realpath, path),
     GVAR_FUNC_0ARGS(LastSystemError),
     GVAR_FUNC_1ARGS(IsExistingFile, filename),
     GVAR_FUNC_1ARGS(IsReadableFile, filename),
