@@ -299,10 +299,6 @@ static Obj  HdlrFunc2 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 4 */
@@ -320,10 +316,6 @@ static Obj  HdlrFunc4 (
  C_LEN_LIST_FPL( t_1, a_args )
  SWITCH_TO_OLD_FRAME(oldFrame);
  return t_1;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 5 */
@@ -351,10 +343,6 @@ static Obj  HdlrFunc5 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 3 */
@@ -566,7 +554,7 @@ static Obj  HdlrFunc3 (
  t_3 = (Obj)R_myopt;
  t_4 = True;
  AssPRec( t_2, (UInt)t_3, t_4 );
- SortPRecRNam( t_2, 0 );
+ SortPRecRNam( t_2 );
  CALL_1ARGS( GF_PushOptions, t_2 );
  if ( TNUM_OBJ( l_vararg__fun ) == T_FUNCTION ) {
   t_2 = CALL_0ARGS( l_vararg__fun );
@@ -590,7 +578,7 @@ static Obj  HdlrFunc3 (
  t_3 = (Obj)R_myopt;
  t_4 = MakeString( "value" );
  AssPRec( t_2, (UInt)t_3, t_4 );
- SortPRecRNam( t_2, 0 );
+ SortPRecRNam( t_2 );
  CALL_1ARGS( GF_PushOptions, t_2 );
  if ( TNUM_OBJ( l_vararg__fun ) == T_FUNCTION ) {
   t_2 = CALL_0ARGS( l_vararg__fun );
@@ -719,7 +707,7 @@ static Obj  HdlrFunc3 (
  t_2 = (Obj)R_myopt;
  t_3 = True;
  AssPRec( t_1, (UInt)t_2, t_3 );
- SortPRecRNam( t_1, 0 );
+ SortPRecRNam( t_1 );
  CALL_1ARGS( GF_PushOptions, t_1 );
  
  /* vararg_fun(  ); */
@@ -734,7 +722,7 @@ static Obj  HdlrFunc3 (
  t_2 = (Obj)R_myopt;
  t_3 = MakeString( "value" );
  AssPRec( t_1, (UInt)t_2, t_3 );
- SortPRecRNam( t_1, 0 );
+ SortPRecRNam( t_1 );
  CALL_1ARGS( GF_PushOptions, t_1 );
  
  /* vararg_fun(  ); */
@@ -749,10 +737,6 @@ static Obj  HdlrFunc3 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 6 */
@@ -1434,10 +1418,6 @@ static Obj  HdlrFunc6 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 7 */
@@ -1470,10 +1450,6 @@ static Obj  HdlrFunc7 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 8 */
@@ -1490,10 +1466,6 @@ static Obj  HdlrFunc8 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 9 */
@@ -1565,8 +1537,8 @@ static Obj  HdlrFunc9 (
  t_6 = NEW_PREC( 0 );
  SET_ELM_PLIST( t_5, 2, t_6 );
  CHANGED_BAG( t_5 );
- SortPRecRNam( t_6, 0 );
- SortPRecRNam( t_3, 0 );
+ SortPRecRNam( t_6 );
+ SortPRecRNam( t_3 );
  if ( TNUM_OBJ( t_1 ) == T_FUNCTION ) {
   CALL_1ARGS( t_1, t_2 );
  }
@@ -1661,7 +1633,7 @@ static Obj  HdlrFunc9 (
  t_1 = NEW_PREC( 1 );
  t_2 = (Obj)R_a;
  AssPRec( t_1, (UInt)t_2, INTOBJ_INT(1) );
- SortPRecRNam( t_1, 0 );
+ SortPRecRNam( t_1 );
  l_x = t_1;
  
  /* x.b := 2; */
@@ -1744,10 +1716,6 @@ static Obj  HdlrFunc9 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 10 */
@@ -1935,7 +1903,7 @@ static Obj  HdlrFunc10 (
  t_1 = NEW_PREC( 1 );
  t_2 = (Obj)R_a;
  AssPRec( t_1, (UInt)t_2, INTOBJ_INT(1) );
- SortPRecRNam( t_1, 0 );
+ SortPRecRNam( t_1 );
  l_x = t_1;
  
  /* Display( IsBound( x.a ) ); */
@@ -1976,7 +1944,7 @@ static Obj  HdlrFunc10 (
  t_1 = NEW_PREC( 1 );
  t_2 = (Obj)R_a;
  AssPRec( t_1, (UInt)t_2, INTOBJ_INT(1) );
- SortPRecRNam( t_1, 0 );
+ SortPRecRNam( t_1 );
  l_x = t_1;
  
  /* Display( IsBound( x.("a") ) ); */
@@ -2020,7 +1988,7 @@ static Obj  HdlrFunc10 (
  t_1 = NEW_PREC( 1 );
  t_2 = (Obj)R_a;
  AssPRec( t_1, (UInt)t_2, INTOBJ_INT(1) );
- SortPRecRNam( t_1, 0 );
+ SortPRecRNam( t_1 );
  l_x = t_1;
  
  /* Display( IsBound( x!.a ) ); */
@@ -2061,7 +2029,7 @@ static Obj  HdlrFunc10 (
  t_1 = NEW_PREC( 1 );
  t_2 = (Obj)R_a;
  AssPRec( t_1, (UInt)t_2, INTOBJ_INT(1) );
- SortPRecRNam( t_1, 0 );
+ SortPRecRNam( t_1 );
  l_x = t_1;
  
  /* Display( IsBound( x!.("a") ) ); */
@@ -2093,10 +2061,6 @@ static Obj  HdlrFunc10 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 11 */
@@ -2289,10 +2253,6 @@ static Obj  HdlrFunc11 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 12 */
@@ -2391,10 +2351,6 @@ static Obj  HdlrFunc12 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 1 */
@@ -2792,10 +2748,6 @@ static Obj  HdlrFunc1 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* 'PostRestore' restore gvars, rnams, functions */
