@@ -85,10 +85,6 @@ static Obj  HdlrFunc2 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 3 */
@@ -124,10 +120,6 @@ static Obj  HdlrFunc3 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 4 */
@@ -172,10 +164,6 @@ static Obj  HdlrFunc4 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 5 */
@@ -219,10 +207,6 @@ static Obj  HdlrFunc5 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 6 */
@@ -266,10 +250,6 @@ static Obj  HdlrFunc6 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 7 */
@@ -323,10 +303,6 @@ static Obj  HdlrFunc7 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 9 */
@@ -343,10 +319,6 @@ static Obj  HdlrFunc9 (
  /* return args; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return a_args;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 10 */
@@ -374,10 +346,6 @@ static Obj  HdlrFunc10 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 11 */
@@ -405,10 +373,6 @@ static Obj  HdlrFunc11 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 12 */
@@ -436,10 +400,6 @@ static Obj  HdlrFunc12 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 13 */
@@ -467,10 +427,6 @@ static Obj  HdlrFunc13 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 14 */
@@ -498,10 +454,6 @@ static Obj  HdlrFunc14 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 15 */
@@ -529,10 +481,6 @@ static Obj  HdlrFunc15 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 8 */
@@ -663,7 +611,7 @@ static Obj  HdlrFunc8 (
  CHECK_BOUND( t_4, "IsList" );
  SET_ELM_PLIST( t_3, 2, t_4 );
  CHANGED_BAG( t_3 );
- t_4 = NewFunction( NameFunc[9], 2, ArgStringToList("func,args"), HdlrFunc9 );
+ t_4 = NewFunction( NameFunc[9], 2, NewPlistFromArgs(MakeImmString("func"), MakeImmString("args")), HdlrFunc9 );
  SET_ENVI_FUNC( t_4, STATE(CurrLVars) );
  t_5 = NewFunctionBody();
  SET_STARTLINE_BODY(t_5, 49);
@@ -922,10 +870,6 @@ static Obj  HdlrFunc8 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* handler for function 1 */
@@ -944,7 +888,7 @@ static Obj  HdlrFunc1 (
       f(  );
       return;
   end; */
- t_1 = NewFunction( NameFunc[2], 1, ArgStringToList("f"), HdlrFunc2 );
+ t_1 = NewFunction( NameFunc[2], 1, NewPlistFromArgs(MakeImmString("f")), HdlrFunc2 );
  SET_ENVI_FUNC( t_1, STATE(CurrLVars) );
  t_2 = NewFunctionBody();
  SET_STARTLINE_BODY(t_2, 2);
@@ -958,7 +902,7 @@ static Obj  HdlrFunc1 (
       f( 1 );
       return;
   end; */
- t_1 = NewFunction( NameFunc[3], 1, ArgStringToList("f"), HdlrFunc3 );
+ t_1 = NewFunction( NameFunc[3], 1, NewPlistFromArgs(MakeImmString("f")), HdlrFunc3 );
  SET_ENVI_FUNC( t_1, STATE(CurrLVars) );
  t_2 = NewFunctionBody();
  SET_STARTLINE_BODY(t_2, 7);
@@ -972,7 +916,7 @@ static Obj  HdlrFunc1 (
       f( 1, 2, 3, 4, 5, 6, 7 );
       return;
   end; */
- t_1 = NewFunction( NameFunc[4], 1, ArgStringToList("f"), HdlrFunc4 );
+ t_1 = NewFunction( NameFunc[4], 1, NewPlistFromArgs(MakeImmString("f")), HdlrFunc4 );
  SET_ENVI_FUNC( t_1, STATE(CurrLVars) );
  t_2 = NewFunctionBody();
  SET_STARTLINE_BODY(t_2, 12);
@@ -986,7 +930,7 @@ static Obj  HdlrFunc1 (
       Display( f(  ) );
       return;
   end; */
- t_1 = NewFunction( NameFunc[5], 1, ArgStringToList("f"), HdlrFunc5 );
+ t_1 = NewFunction( NameFunc[5], 1, NewPlistFromArgs(MakeImmString("f")), HdlrFunc5 );
  SET_ENVI_FUNC( t_1, STATE(CurrLVars) );
  t_2 = NewFunctionBody();
  SET_STARTLINE_BODY(t_2, 18);
@@ -1000,7 +944,7 @@ static Obj  HdlrFunc1 (
       Display( f( 1 ) );
       return;
   end; */
- t_1 = NewFunction( NameFunc[6], 1, ArgStringToList("f"), HdlrFunc6 );
+ t_1 = NewFunction( NameFunc[6], 1, NewPlistFromArgs(MakeImmString("f")), HdlrFunc6 );
  SET_ENVI_FUNC( t_1, STATE(CurrLVars) );
  t_2 = NewFunctionBody();
  SET_STARTLINE_BODY(t_2, 23);
@@ -1014,7 +958,7 @@ static Obj  HdlrFunc1 (
       Display( f( 1, 2, 3, 4, 5, 6, 7 ) );
       return;
   end; */
- t_1 = NewFunction( NameFunc[7], 1, ArgStringToList("f"), HdlrFunc7 );
+ t_1 = NewFunction( NameFunc[7], 1, NewPlistFromArgs(MakeImmString("f")), HdlrFunc7 );
  SET_ENVI_FUNC( t_1, STATE(CurrLVars) );
  t_2 = NewFunctionBody();
  SET_STARTLINE_BODY(t_2, 28);
@@ -1085,10 +1029,6 @@ static Obj  HdlrFunc1 (
  /* return; */
  SWITCH_TO_OLD_FRAME(oldFrame);
  return 0;
- 
- /* return; */
- SWITCH_TO_OLD_FRAME(oldFrame);
- return 0;
 }
 
 /* 'PostRestore' restore gvars, rnams, functions */
