@@ -7,7 +7,7 @@ set -ex
 GAPDIR=${GAPDIR:-../..}
 
 retvalue=0
-gap="$GAPDIR/bin/gap.sh"
+gap="$GAPDIR/gap"
 if "${gap}" -A -b -c 'QuitGap(GAPInfo.BytesPerVariable - 8);'; then
     echo "Running 64-bit special tests"
     tocheck="*.g 64bit/*.g"
